@@ -701,6 +701,7 @@ public:
 				bool flashing;
 				bool dialing;
 				bool exiting;
+				bool hangup;
 				bool dtmf;
 				char *syncdigit;
 				timeout_t synctimer;
@@ -722,7 +723,7 @@ public:
 			{
 				const char *dial;
 				const char *exit;
-				bool dtmf, drop;
+				bool dtmf, drop, hangup;
 				BayonneSession *peer;
 				timeout_t answer_timer, hunt_timer;
 				Line *select;
@@ -2657,9 +2658,27 @@ protected:
          */
         virtual void startService(void);
 
+	/**
+	 * Used at end of call.
+	 */
+	virtual void detachCall(BayonneSession *s);
+
+	/**
+	 * Used at running state.
+	 */
+	virtual void activeCall(BayonneSession *s);
+
+	/**
+	 * Used to notify for an extension ringing.
+	 */
+	virtual void notifyCall(BayonneSession *s);
+
 public:
 	static void start(void);
 	static void stop(void); 
+	static void detach(BayonneSession *s);
+	static void active(BayonneSession *s);
+	static void notify(BayonneSession *s);
 };
 
 } // namespace
