@@ -532,7 +532,7 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count)
 			data[idx].status = "invalid";
 		else if(!reg->traffic->active)
 			data[idx].status = "failed";
-		else if(reg->getTimer() > 0)
+		else if(reg->traffic->getTimer() > 0)
 		{
 			if(!reg->call_limit || reg->traffic->active_calls < reg->call_limit)
 				data[idx].status = "active";
@@ -1253,12 +1253,12 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(ext)
 	{
 		if(!ScriptChecks::useKeywords(line, 
-			"=secret=encoding=framing=dtmf=user=count=device"))
+			"=secret=encoding=framing=dtmf=user=count=device=info"))
 				return "invalid keywords used for sip external";
 	}
 	else if(!ScriptChecks::useKeywords(line, 
 		"=uri=timeout=server=proxy=userid=secret=type=realm=dtmf"
-		"=limit=public=encoding=framing=local=caller"))
+		"=limit=public=encoding=framing=local=caller=service"))
 			return "invalid keywords for sip registry";
 
 
@@ -1279,7 +1279,19 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(ext)
 		reg->localid = ScriptChecks::findKeyword(line, "user");
 	else
+	{
+		reg->service = ScriptChecks::findKeyword(line, "service");
 		reg->localid = ScriptChecks::findKeyword(line, "local");
+		if(reg->service && !reg->localid)
+			reg->localid = reg->service;
+	}
+
+	if(!reg->service)
+	{
+		reg->service = scr->name;
+		if(!strnicmp(reg->service, "sip::", 5))
+			reg->service += 5;
+	}
 
 	cp = ScriptChecks::findKeyword(line, "limit");
 	if(cp)
@@ -1452,6 +1464,10 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		reg->localid = (const char *)img->getMemory(len);
 		strcpy((char *)reg->localid, buf + 4);
 	}
+//** ADDED
+	else
+		setString(buf + 4, sizeof(buf) - 4, reg->localid);
+
         if(!reg->userid)
                 reg->userid = reg->localid; 
 
@@ -1585,6 +1601,13 @@ add:
 	img->setPointer(buf, reg);
 	img->addRegistration(line);
 	line->scr.registry = reg;
+	if(ext)
+	{
+		snprintf(buf, sizeof(buf), "uid.%s", reg->localid);
+		img->setPointer(buf, line);
+		snprintf(buf, sizeof(buf), "ext.%s", reg->localid);
+		img->setPointer(buf, &Driver::sip);
+	}
 
 	return "";
 }
@@ -1613,7 +1636,7 @@ void Driver::run(void)
         Event event;
 	char buf[1024];
 	char cbuf[256];
-	Registry *reg, *peer, *proxy;
+	Registry *reg, *peer, *proxy, *sreg;
 	Name *scr;
 	ScriptImage *img;
 	const char *cp;
@@ -1647,6 +1670,7 @@ void Driver::run(void)
 	uint8 reg_payload;
 	timeout_t expires;
 	unsigned thread = ++instance;
+	unsigned short sinstance;
 	time_t now;
 	time_t last = 0;
 
@@ -1674,6 +1698,8 @@ void Driver::run(void)
 		slog.debug("sip: event %04x; cid=%d, did=%d, rid=%d, instance=%d",
 			sevent->type, sevent->cid, sevent->did, sevent->rid, thread);
 
+		sreg = NULL;
+		sinstance = 0;
 		switch(sevent->type)
 		{
 		case EXOSIP_REGISTRATION_NEW:
@@ -1694,7 +1720,7 @@ void Driver::run(void)
 			if(reg && !expires)
 			{
 				reg->traffic->active = false;
-				slog.debug("registration for %s rejected", reg->contact);
+				slog.debug("registration for %s rejected", reg->service);
 			}
 			else if(reg)
 			{
@@ -1704,11 +1730,11 @@ void Driver::run(void)
 				{
 					updateExpires(reg, expires);
 					slog.debug("registration for %s updated for %d seconds",
-						reg->contact, reg->duration / 1000);			
+						reg->service, reg->duration / 1000);			
 				}
 				else
 					slog.debug("registration for %s confirmed for %d seconds", 
-						reg->contact, expires / 1000);
+						reg->service, expires / 1000);
 			}
 			else
 				slog.warn("unknown sip registration confirmed; rid=%s", sevent->rid);
@@ -1733,7 +1759,7 @@ void Driver::run(void)
 			{
 				reg->traffic->setTimer(0);
 				reg->traffic->active = false;
-				slog.info("registration for %s failed", reg->contact);
+				slog.info("registration for %s failed", reg->service);
 			}
 			else
 				slog.warn("unknown sip registration failed; rid=%s", sevent->rid);
@@ -1852,6 +1878,10 @@ void Driver::run(void)
 			}
 			break;				
 		case EXOSIP_CALL_CLOSED:
+			session = getCall(sevent->cid);
+			if(session)
+				goto exitcall;
+			break;
 		case EXOSIP_CALL_CANCELLED:
 			session = getCall(sevent->cid);
 			if(!session)
@@ -2499,7 +2529,9 @@ validate:
 				if(!reg->isActive())
 					goto sip404;
 	
-				if(reg->call_limit && reg->traffic->active_calls >= reg->call_limit)
+				sreg = reg;
+				sinstance = ++reg->traffic->active_calls;
+				if(reg->call_limit && sinstance > reg->call_limit)
 					goto sip480;
 
 				scr = img->getScript(reg->scr->name);
@@ -2601,7 +2633,6 @@ sip480:
 
 			if(reg)
 			{
-				++reg->traffic->active_calls;
 				++reg->traffic->call_attempts.iCount;
 				++reg->traffic->call_complete.iCount;
 				if(!stricmp(reg->type, "anon") || !strnicmp(reg->type, "ext", 3))
@@ -2614,6 +2645,15 @@ sip480:
 
 				if(reg->encoding)
 					session->setEncoding(reg->encoding, reg->framing);
+
+				if(!strnicmp(reg->type, "ext", 3))
+					session->setConst("session.identity", reg->localid);
+				else
+					session->setConst("session.service", reg->service);
+			
+				snprintf(digit, sizeof(digit), "%d", sinstance);
+				session->setConst("session.instance", digit);
+				BayonneService::notify(session);
 			}
 			else
 			{
@@ -2623,7 +2663,14 @@ sip480:
 				if(p && !stricmp(p, ":5060"))
 					*p = 0;
 				session->setConst("session.uri_local", buf);
+				session->setConst("session.service", "anonymous");
 			}
+                        snprintf(digit, sizeof(digit), "%d", sinstance);                                
+			session->setConst("session.instance", digit);
+                        BayonneService::notify(session);
+
+			sinstance = 0;
+			sreg = NULL;
 				
                         session->local_address = getLast("localip");
                         snprintf(buf, sizeof(buf), "%s:%d",
@@ -2867,6 +2914,11 @@ clear:
 				add(session);
 
 cleanup:
+			if(sreg && sinstance)
+				--sreg->traffic->active_calls;
+
+			sinstance = 0;
+			sreg = NULL;
 			eXosip_lock();
 //			if(msg)
 //				osip_message_free(msg);
