@@ -120,7 +120,7 @@ public:
 	const char *address;
 	const char *hostid;
 	const char *portid;
-	const char *userid, *localid;
+	const char *userid, *localid, *service;
 	const char *secret;
 	const char *type;
 	const char *realm;
@@ -129,7 +129,7 @@ public:
 	const char *caller;
 	timeout_t framing;
 	int regid;
-	short call_limit;
+	unsigned short call_limit;
 
 	bool insecure_publish;
 
