@@ -281,6 +281,7 @@ bool Session::enterSeize(Event *event)
 	Name *scr;
 	unsigned idx;
 	bool offline = false;
+	unsigned short instance = 0;
 
 	switch(event->id)
 	{
@@ -304,6 +305,10 @@ bool Session::enterSeize(Event *event)
 			{
 				idx = state.join.index++;
 				cp = state.join.select->args[idx];
+				if(idx < state.join.select->argc)
+					cp = state.join.select->args[idx];
+				else
+					cp = NULL;
 				if(!cp)
 				{
 					state.join.select =
@@ -373,8 +378,10 @@ dialer:
 				default:
 					break;
 				}
-				if(reg->call_limit && reg->traffic->active_calls >= reg->call_limit)
+				instance = ++reg->traffic->active_calls;
+				if(reg->call_limit && instance > reg->call_limit)
 				{
+					--reg->traffic->active_calls;
 					event->id = DIAL_BUSY;
 					return false;
 				}
@@ -426,7 +433,8 @@ dialing:
 			if(!route)
 				route = reg->proxy;
 
-			++reg->traffic->active_calls;
+			if(!instance)
+				instance = ++reg->traffic->active_calls;
 			++reg->traffic->call_attempts.oCount;
 			++reg->traffic->call_complete.oCount;
 			if(!strnicmp(reg->type, "ext", 3))
@@ -451,6 +459,15 @@ dialing:
                         }
                         else
                                 setConst("session.ip_public", lp);
+
+			if(!strnicmp(reg->type, "ext", 3))
+				setConst("session.identity", reg->localid);
+			else
+				setConst("session.service", reg->service);
+
+			snprintf(nbuf, sizeof(nbuf), "%d", instance);
+			setConst("session.instance", nbuf);
+			BayonneService::notify(this);
 		}
 		else
 		{
@@ -460,8 +477,12 @@ dialing:
 			setConst("session.uri_caller", buf);
                         setConst("session.ip_local", lp);
                         setConst("session.ip_public", lp);
+			setConst("session.service", "anonymous");
 		}
-			
+                snprintf(nbuf, sizeof(nbuf), "%d", instance);
+                setConst("session.instance", nbuf);
+                BayonneService::notify(this);
+					
 		to = getSymbol("session.uri_remote");
 		from = getSymbol("session.uri_caller");
 
@@ -633,7 +654,7 @@ bool Session::enterHangup(Event *event)
 			break;
 		reg = (Registry *)img->getPointer(cp);
 		if(reg)
-			--reg->traffic->active_calls;	
+			--reg->traffic->active_calls;
 		break;
 	case TIMER_EXPIRED:
 		if(!rtp_flag)
