@@ -15,7 +15,9 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "module.h"
+#ifndef	WIN32
 #include "private.h"
+#endif
 #include <cerrno>
 
 namespace moduleWebservice {
@@ -135,21 +137,25 @@ void Session::syncExit(void)
 	Thread::exit();
 }
 
-void Session::sendError(const char *text, const char *ctype)
+#ifndef	VERSION
+#define	VERSION "w32"
+#endif
+
+void Session::sendError(const char *text, const char *cttype)
 {
 	sendText(text);
 	sendText("Server: Bayonne/" VERSION "\r\n");
 	sendText("Connection: close\r\n");
-	if(ctype)
+	if(cttype)
 	{
 		snprintf(buffer, sizeof(buffer), 
-			"Conection-Type: %s\r\n", ctype);
+			"Conection-Type: %s\r\n", cttype);
 		sendText(buffer);
 	}
 	sendText("\r\n");
 }
 
-void Session::sendAuth(const char *text, const char *ctype)
+void Session::sendAuth(const char *text, const char *cttype)
 {
 	const char *realm = Service::webservice.getLast("realm");
         sendText(text);
@@ -158,15 +164,19 @@ void Session::sendAuth(const char *text, const char *ctype)
 	snprintf(buffer, sizeof(buffer),
 		"WWW-Authenticate: Basic realm=\"%s\"\r\n", realm);
 	sendText(buffer);
-        if(ctype)
+        if(cttype)
         {
                 snprintf(buffer, sizeof(buffer),
-                        "Conection-Type: %s\r\n", ctype);
+                        "Conection-Type: %s\r\n", cttype);
                 sendText(buffer);
         }
         sendText("\r\n");
 }
 
+#ifndef	ECONNRESET
+#define	ECONNRESET -99
+#endif
+
 void Session::sendText(const char *text)
 {
 	int flag = 0;
@@ -181,14 +191,14 @@ void Session::sendText(const char *text)
 	}
 }
 
-void Session::sendHeader(const char *ctype, unsigned long clen)
+void Session::sendHeader(const char *cttype, unsigned long clen)
 {
 	char buf[96];
 	sendText("HTTP/1.1 200 OK\r\n");
 	sendText("Connection: close\r\n");
 	snprintf(buf, sizeof(buf), "Server: Bayonne/%s\r\n", VERSION);
 	sendText(buf);
-	snprintf(buf, sizeof(buf), "Connection-Type: %s\r\n", ctype);
+	snprintf(buf, sizeof(buf), "Connection-Type: %s\r\n", cttype);
 	sendText(buf);	
 
 	if(clen)
