@@ -165,6 +165,14 @@ class Libexec:
 		self.tsession = ""
 		return
 
+	def error(self, code):
+		if self.tsession == "" or not self.tsession or self.exitcode != 0:
+			return
+		sys.stdout.write("%s ERROR %s\n" % (self.tsession, code))
+		sys.stdout.flush()
+		self.tsession = ""
+		return
+
 	def detach(self, code):
 		if self.tsession == "" or not self.tsession or self.exitcode != 0:
                         return     
