@@ -464,6 +464,26 @@ bool Methods::scrRoute(void)
 	error("no-digit-match");
 	return true;
 }
+
+bool Methods::scrSRoute(void)
+{
+	const char *cp = getMember();
+	const char *opt;
+	char evt[65];
+	
+	if(!cp)
+		cp = "digits";
+
+	while(NULL != (opt = getValue(NULL)))
+	{
+		snprintf(evt, sizeof(evt), "%s:%s", cp, opt);
+		if(scriptEvent(evt))
+			return false;
+	}
+	
+	error("no-string-match");
+	return true;
+}
 	
 bool Methods::scrCollect(void)
 {
